from django.conf import settings
from django.core.mail.backends.base import BaseEmailBackend

from djcelery_email.tasks import SendEmailTask


class CeleryEmailBackend(BaseEmailBackend):
    
    def send_messages(self, email_messages):
        for msg in email_messages:
            SendEmailTask.delay(msg)


from celery.task import Task
from django.core.mail import get_connection

CELERY_EMAIL_BACKEND = getattr(settings, 'CELERY_EMAIL_BACKEND',
                               'django.core.mail.backends.smtp.EmailBackend')


class SendEmailTask(Task):
    #default_retry_delay = 60 * 5
    ignore_result = True
    
    def run(self, message, **kwargs):
        logger = self.get_logger(**kwargs)
        conn = get_connection(backend=CELERY_EMAIL_BACKEND)
        try:
            conn.send_messages([message])
            logger.debug("Successfully sent email message to %r.", message.to)
        except:
            # catching all exceptions b/c it could be any number of things
            # depending on the backend
            try:
                self.retry([message], kwargs)
                logger.info("Failed to send email message to %r, retrying.",
                            message.to)
            except self.MaxRetriesExceededError:
                logger.error("Max retries exceeded trying to send email to %r.",
                             message.to)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys
import codecs
import platform

try:
    from setuptools import setup, find_packages, Command
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages, Command

import djcelery_email as distmeta


class RunTests(Command):
    description = "Run the django test suite from the tests dir."
    user_options = []

    def run(self):
        this_dir = os.getcwd()
        testproj_dir = os.path.join(this_dir, "test_project")
        os.chdir(testproj_dir)
        sys.path.append(testproj_dir)
        from django.core.management import execute_manager
        os.environ["DJANGO_SETTINGS_MODULE"] = os.environ.get(
                        "DJANGO_SETTINGS_MODULE", "settings")
        settings_file = os.environ["DJANGO_SETTINGS_MODULE"]
        settings_mod = __import__(settings_file, {}, {}, [''])
        execute_manager(settings_mod, argv=[
            __file__, "test"])
        os.chdir(this_dir)

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass


if os.path.exists("README.rst"):
    long_description = codecs.open("README.rst", "r", "utf-8").read()
else:
    long_description = "See http://pypi.python.org/pypi/django-celery-email"


setup(
    name='django-celery-email',
    version=distmeta.__version__,
    description=distmeta.__doc__,
    author=distmeta.__author__,
    author_email=distmeta.__contact__,
    url=distmeta.__homepage__,
    platforms=["any"],
    license="BSD",
    packages=find_packages(exclude=['ez_setup', 'test_project', 'test_project.*']),
    scripts=[],
    zip_safe=False,
    install_requires=[
        "django-celery>=2.0.0",
    ],
    cmdclass = {"test": RunTests},
    classifiers=[
        "Development Status :: 4 - Beta",
        "Framework :: Django",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: POSIX",
        "Topic :: Communications",
        "Topic :: Communications :: Email",
        "Topic :: System :: Distributed Computing",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    entry_points={},
    long_description=long_description,
)
